@@ -1,7 +1,3 @@
-#include "about.h"
-#include "cmd.h"
-#include "version.h"
-
 #include <QApplication>
 #include <QFileInfo>
 #include <QMessageBox>
@@ -9,6 +5,11 @@
 #include <QTextEdit>
 #include <QVBoxLayout>
 
+#include "about.h"
+#include "cmd.h"
+#include "version.h"
+
+
 // display doc as nomal user when run as root
 void displayDoc(QString url, QString title, bool runned_as_root)
 {
@@ -20,7 +21,7 @@ void displayDoc(QString url, QString title, bool runned_as_root)
         } else {
             Cmd cmd;
             QString user = cmd.getCmdOut("/usr/bin/logname", true);
-            system("su " + user.toUtf8() + " -c \"env XDG_RUNTIME_DIR=/run/user/$(id -u " +
+            system("runuser -l " + user.toUtf8() + " -c \"env XDG_RUNTIME_DIR=/run/user/$(id -u " +
                    user.toUtf8() + ") /usr/bin/xdg-open " + url.toUtf8() + "\"&");
         }
     }
